@@ -27,7 +27,7 @@ class parse(object):
 
     def getStampFileName(self):
         self.md5name = md5.md5(self.feed_url).hexdigest()
-        self.directory = os.path.expanduser("~/.rss2twitter/")
+        self.directory = os.path.expanduser("~/.feed2twitter/")
         self.filename = self.directory + self.md5name
 
     def updateLastRead(self,item=None):
